import { AccessibleViewType, AccessibleViewProviderId } from 'vscode/vscode/vs/platform/accessibility/browser/accessibleView';
import { ContextKeyExpr } from 'vscode/vscode/vs/platform/contextkey/common/contextkey';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { getReplView } from './repl.js';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';
import { AccessibilityVerbositySettingId } from 'vscode/vscode/vs/workbench/contrib/accessibility/browser/accessibilityConfiguration';
import { localize } from 'vscode/vscode/vs/nls';
import { AccessibilityHelpNLS } from 'vscode/vscode/vs/editor/common/standaloneStrings';

class ReplAccessibilityHelp {
    constructor() {
        this.priority = 120;
        this.name = 'replHelp';
        this.when = ( (ContextKeyExpr.equals('focusedView', 'workbench.panel.repl.view')));
        this.type = AccessibleViewType.Help;
    }
    getProvider(accessor) {
        const viewsService = accessor.get(IViewsService);
        const replView = getReplView(viewsService);
        if (!replView) {
            return undefined;
        }
        return (
             (new ReplAccessibilityHelpProvider(replView))
        );
    }
}
class ReplAccessibilityHelpProvider extends Disposable {
    constructor(_replView) {
        super();
        this._replView = _replView;
        this.id = AccessibleViewProviderId.ReplHelp;
        this.verbositySettingKey = AccessibilityVerbositySettingId.Debug;
        this.options = { type: AccessibleViewType.Help };
        this._treeHadFocus = false;
        this._treeHadFocus = !!_replView.getFocusedElement();
    }
    onClose() {
        if (this._treeHadFocus) {
            return this._replView.focusTree();
        }
        this._replView.getReplInput().focus();
    }
    provideContent() {
        return [
            ( localize(
                6115,
                "The debug console is a Read-Eval-Print-Loop that allows you to evaluate expressions and run commands and can be focused with{0}.",
                '<keybinding:workbench.panel.repl.view.focus>'
            )),
            ( localize(
                6116,
                "The debug console output can be navigated to from the input field with the Focus Previous Widget command{0}.",
                '<keybinding:widgetNavigation.focusPrevious>'
            )),
            ( localize(
                6117,
                "The debug console input can be navigated to from the output with the Focus Next Widget command{0}.",
                '<keybinding:widgetNavigation.focusNext>'
            )),
            ( localize(
                6118,
                "The debug console output history can be navigated with the up and down arrow keys."
            )),
            ( localize(
                6119,
                "The Open Accessible View command{0} will allow character by character navigation of the console output.",
                '<keybinding:editor.action.accessibleView>'
            )),
            ( localize(
                6120,
                "The Show Run and Debug view command{0} will open the Run and Debug view.",
                '<keybinding:workbench.view.debug>'
            )),
            AccessibilityHelpNLS.setBreakpoint,
            ( localize(
                6121,
                "The setting `debug.expandLazyVariables` controls whether variables are evaluated automatically. This is enabled by default when using a screen reader."
            )),
            ( localize(
                6122,
                "The Debug: Continue command{0} will continue execution until the next breakpoint.",
                '<keybinding:workbench.action.debug.continue>'
            )),
            ( localize(
                6123,
                "The Debug: Step Into command{0} will step into the next function call.",
                '<keybinding:workbench.action.debug.stepInto>'
            )),
            ( localize(
                6124,
                "The Debug: Step Over command{0} will step over the current function call.",
                '<keybinding:workbench.action.debug.stepOver>'
            )),
            ( localize(
                6125,
                "The Debug: Step Out command{0} will step out of the current function call.",
                '<keybinding:workbench.action.debug.stepOut>'
            )),
        ].join('\n');
    }
}

export { ReplAccessibilityHelp };
